# class LightCustomButton(ButtonBehavior, BoxLayout):
#     text = StringProperty("Hello World")
#     font_size = NumericProperty(sp(18))
#     icon = StringProperty()
#     bg_color = ColorProperty([1, 1, 1, 1])
#     color = ColorProperty([0, 0, 0, 1])
#     icon_color = ColorProperty([0, 0, 0, 1])
#     radius = ListProperty([dp(5)])
#     icon_size = NumericProperty(sp(24))
